<template>
  <LoadingLayout :loading="isLoading" :error="isError" :loadError="refetch">
    <JobDetailContent :isCollapse="true">
      <template #footer>
        <PageFooterBtn
          type="primary"
          plain
          @click="taskWorkerHireRefuse(FlexTaskWorkerHireEnum.Refused)"
          >谢绝</PageFooterBtn
        >
        <PageFooterBtn type="primary" @click="taskWorkerHireRefuse(FlexTaskWorkerHireEnum.Hired)"
          >录用</PageFooterBtn
        >
      </template>
    </JobDetailContent>
  </LoadingLayout>
</template>

<script setup lang="ts">
import Taro from '@tarojs/taro';
import { useQuery } from '@tanstack/vue-query';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import { Message } from '@12333/utils';
import { FlexTaskWorkerHireEnum } from '@/constants/task';

defineOptions({
  name: 'InnerPage',
});

const router = Taro.useRouter();
const taskId = router.params?.id ?? '';

const {
  isLoading,
  isError,
  data: detail,
  refetch,
} = useQuery({
  queryKey: ['flexWorkerServices/getFlexTaskDto', taskId],
  queryFn: async () => {
    return await flexWorkerServices.getFlexTaskDto(
      { id: taskId },
      {
        showLoading: false,
      }
    );
  },
  placeholderData: () => ({} as API.GetFlexTaskDtoOutput),
});

async function taskWorkerHireRefuse(hireStatus: FlexTaskWorkerHireEnum) {
  try {
    let params: API.TaskWorkerHireRefuseInput = {
      flexTaskId: taskId,
      flexWorkerId: detail.value?.taskId,
      hireStatus: hireStatus,
    };
    let res = await flexWorkerServices.taskWorkerHireRefuse(params);
    if (res) {
      Message.success('操作成功');
      refetch({
        type: 'inactive',
      });
    }
  } catch (error) {}
}
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
